"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var React = require("react");
var ReactDom = require("react-dom");
var sp_core_library_1 = require("@microsoft/sp-core-library");
var sp_webpart_base_1 = require("@microsoft/sp-webpart-base");
var pnp = require("sp-pnp-js");
var BannerWp_1 = require("./components/BannerWp/BannerWp");
var strings = require("bannerWpStrings");
var BannerWpWebPart = (function (_super) {
    __extends(BannerWpWebPart, _super);
    function BannerWpWebPart() {
        var _this = _super.call(this) || this;
        _this.bannerWpFields = [];
        pnp.setup({
            headers: {
                'Accept': 'application/json;odata=nometadata'
            }
        });
        _this.options = _this._getLists();
        return _this;
    }
    BannerWpWebPart.prototype.render = function () {
        var element = React.createElement(BannerWp_1.default, {
            scrollSpeed: (1 / this.properties.scrollSpeed),
            title: this.properties.title,
            imgListId: this.properties.imgListId,
            showBulletButtons: this.properties.showBulletButtons,
            showThumpnails: this.properties.showThumpnails
        });
        ReactDom.render(element, this.domElement);
    };
    Object.defineProperty(BannerWpWebPart.prototype, "dataVersion", {
        get: function () {
            return sp_core_library_1.Version.parse('1.0');
        },
        enumerable: true,
        configurable: true
    });
    BannerWpWebPart.prototype.getPropertyPaneConfiguration = function () {
        var templateToggle;
        if (this.properties.newLToggle) {
            templateToggle = [
                sp_webpart_base_1.PropertyPaneTextField('newListName', {
                    label: strings.PPaneListName
                }),
                sp_webpart_base_1.PropertyPaneTextField('newListDescription', {
                    label: strings.PPaneListDesc
                }),
                sp_webpart_base_1.PropertyPaneCheckbox('isContentTypeEnabled', {
                    text: strings.PPaneListCheckboxTitle
                }),
                sp_webpart_base_1.PropertyPaneButton('', {
                    buttonType: sp_webpart_base_1.PropertyPaneButtonType.Normal,
                    text: strings.PPaneListButtonTittle,
                    onClick: this._createNewList.bind(this)
                })
            ];
        }
        else {
            templateToggle = [
                sp_webpart_base_1.PropertyPaneDropdown('imgListId', {
                    label: strings.PPaneDropdownTitle,
                    options: this.options,
                    selectedKey: strings.PPaneDropdownSelectedKey
                }),
                {
                    type: sp_webpart_base_1.PropertyPaneFieldType.Custom,
                    targetProperty: '',
                    properties: {
                        onRender: this._customFieldRender.bind(this),
                        value: undefined,
                        context: undefined
                    }
                }
            ];
        }
        return {
            pages: [
                {
                    header: {
                        description: strings.header
                    },
                    groups: [
                        {
                            groupName: strings.BasicGroupName,
                            groupFields: [
                                sp_webpart_base_1.PropertyPaneSlider('scrollSpeed', {
                                    label: strings.PPaneSliderTittle,
                                    min: 1,
                                    max: 5,
                                    step: 0.5,
                                    value: 2
                                }),
                                sp_webpart_base_1.PropertyPaneToggle('showBulletButtons', {
                                    label: strings.PPaneToggleBullets,
                                    onText: strings.PPaneToggleOn,
                                    offText: strings.PPaneToggleOff
                                }),
                                sp_webpart_base_1.PropertyPaneToggle('showThumpnails', {
                                    label: strings.PPaneToggleThumpnails,
                                    onText: strings.PPaneToggleOn,
                                    offText: strings.PPaneToggleOff
                                }),
                                sp_webpart_base_1.PropertyPaneToggle('newLToggle', {
                                    label: strings.PPaneToggleList,
                                    onText: strings.PPaneToggleListOn,
                                    offText: strings.PPaneToggleListOff
                                })
                            ]
                        },
                        {
                            groupName: strings.ImgListGroupName,
                            groupFields: templateToggle
                        }
                    ]
                }
            ]
        };
    };
    /**
     * Uses Sharepoint API to retrieve a list of picture lists and add it to the options of the dropdown on the property pane.
     */
    BannerWpWebPart.prototype._getLists = function () {
        var _this = this;
        var optionsList = [];
        pnp.sp.web.lists.filter('BaseTemplate eq 109').get().then(function (items) {
            for (var i = 0; i < items.length; i++) {
                optionsList.push({
                    index: i,
                    key: items[i].Id,
                    text: items[i].Title
                });
            }
            if (items.length === 0) {
                _this.properties.hasImages = false;
            }
            _this.properties.hasImages = true;
        }, function (error) {
            console.log('Error');
        });
        return optionsList;
    };
    /**
     * Uses the Sharepoint API to create a new list with the active custom field.
     */
    BannerWpWebPart.prototype._createNewList = function (elem) {
        var _this = this;
        var fieldXML = "<Field DisplayName='Ativo' Type='Boolean' Required='TRUE' Name='ativo' Group='Custom Columns' />";
        pnp.sp.web.lists.add(this.properties.newListName, this.properties.newListDescription, 109, this.properties.isContentTypeEnabled).then(function () {
            pnp.sp.web.lists.getByTitle(_this.properties.newListName).fields.createFieldAsXml(fieldXML)
                .then(function () {
                pnp.sp.web.lists.getByTitle(_this.properties.newListName).fields.addUrl('Link').then(function () {
                    _this.properties.newListDescription = undefined;
                    _this.properties.newListName = undefined;
                    _this.properties.isContentTypeEnabled = false;
                    _this.properties.newLToggle = false;
                    _this.options = _this._getLists();
                    _this.context.propertyPane.refresh();
                });
            });
        });
    };
    /**
     * Renders the custom upload button on the Property Pane.
     * @param elem Html HTMLElement onto which to load the button.
     */
    BannerWpWebPart.prototype._customFieldRender = function (elem) {
        if (this.properties.imgListId != null)
            pnp.sp.web.lists.getById(this.properties.imgListId).select('url').expand('RootFolder, ParentWeb')
                .select('Title,RootFolder/ServerRelativeUrl, ParentWeb/Url').get().then(function (response) {
                var uri;
                if (response != null) {
                    debugger;
                    uri = encodeURI(response.ParentWeb.Url + '/' + response.Title);
                    elem.innerHTML = "<span class='ms-Button-description'><a class='ms-Link ms-button' href = " + uri + ">" + strings.PPaneBTNImageUpload + "</a></span>";
                }
                else {
                    elem.innerHTML = '';
                }
            });
    };
    return BannerWpWebPart;
}(sp_webpart_base_1.BaseClientSideWebPart));
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = BannerWpWebPart;

//# sourceMappingURL=BannerWpWebPart.js.map
