import * as React from 'react';
import { IBannerWpProps } from './IBannerWpProps';
import { ISPImage } from '../ISPImage';
export interface IBannerState {
    imgs: ISPImage[];
    listId: string;
    hasImages: boolean;
}
export interface IGalleryState {
    bullets: boolean;
    thumpnails: boolean;
    scroll: number;
}
export default class BannerWp extends React.Component<IBannerWpProps, IBannerState> {
    private lastId;
    private gallery;
    constructor(props: any);
    /**
     * Renders the react component.
     * Default component - If there is no list selected or images on the selected list.
     * Carousel component -  If there are images on the selected list.
     *
     */
    render(): JSX.Element;
    /**
     * Is called after a property change. Verifies if it is necessary to update the state and acts accordingly.
     * @param nextProps new properties passed down from the Property Pane.
     */
    componentWillReceiveProps(nextProps: IBannerWpProps): void;
    /**
     * Uses Sharepoint API to retrieve the items from a specific list and updates the state of the component.
     * @param listId the id of the list from which to retrieve the items.
     */
    private _loadImagesURLFromSP(listId);
    /**
     * Receives the response from an Sharepoint API request and processes it into an ISPImage array.
     * @param items the response with from the SharePoint API
     * @param list to load the images onto.
     */
    private _processImages(items, list);
    /**
     * Receives the response from an Sharepoint API request and processes it adding ther URL of the images to an ISPImage array.
     * @param items the response with from the SharePoint API
     * @param list of images to load the urls onto.
     */
    private _processUrls(items, list);
    private _validateNextGallery(nextProps);
}
