"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var React = require("react");
var strings = require("bannerWpStrings");
var pnp = require("sp-pnp-js");
var Carousel_1 = require("../Carousel/Carousel");
var Default_1 = require("../Default/Default");
var BannerWp = (function (_super) {
    __extends(BannerWp, _super);
    function BannerWp(props) {
        var _this = _super.call(this, props) || this;
        _this.state = _this._loadImagesURLFromSP(_this.props.imgListId);
        _this.lastId = '';
        _this.gallery = {
            bullets: _this.props.showBulletButtons,
            scroll: _this.props.scrollSpeed,
            thumpnails: _this.props.showThumpnails
        };
        return _this;
    }
    /**
     * Renders the react component.
     * Default component - If there is no list selected or images on the selected list.
     * Carousel component -  If there are images on the selected list.
     *
     */
    BannerWp.prototype.render = function () {
        debugger;
        if (this.state.hasImages) {
            return (React.createElement("div", null,
                React.createElement(Carousel_1.default, { title: this.props.title, images: this.state.imgs, scrollSpeed: this.props.scrollSpeed * 5000, showBulletButtons: this.props.showBulletButtons, showThumpnails: this.props.showThumpnails, listId: this.state.listId })));
        }
        return (React.createElement(Default_1.default, { message: strings.WPDefaultDescription }));
    };
    /**
     * Is called after a property change. Verifies if it is necessary to update the state and acts accordingly.
     * @param nextProps new properties passed down from the Property Pane.
     */
    BannerWp.prototype.componentWillReceiveProps = function (nextProps) {
        debugger;
        if (this.state.listId !== nextProps.imgListId) {
            this.lastId = this.state.listId;
            this._loadImagesURLFromSP(nextProps.imgListId);
        }
    };
    /**
     * Uses Sharepoint API to retrieve the items from a specific list and updates the state of the component.
     * @param listId the id of the list from which to retrieve the items.
     */
    BannerWp.prototype._loadImagesURLFromSP = function (listId) {
        var _this = this;
        var state = {
            hasImages: false,
            imgs: [],
            listId: listId
        };
        if (listId != null) {
            pnp.sp.web.lists.getById(listId).items.filter('Ativo eq 1').get().then(function (items) { return _this._processImages(items, state.imgs); })
                .then(function () {
                pnp.sp.web.lists.getById(listId).items.filter('Ativo eq 1').select('EncodedAbsUrl').get()
                    .then(function (items) {
                    _this._processUrls(items, state.imgs);
                    if (state.imgs.length > 0)
                        state.hasImages = true;
                    _this.setState(state);
                });
            });
        }
        return state;
    };
    /**
     * Receives the response from an Sharepoint API request and processes it into an ISPImage array.
     * @param items the response with from the SharePoint API
     * @param list to load the images onto.
     */
    BannerWp.prototype._processImages = function (items, list) {
        debugger;
        for (var i = 0; i < items.length; i++) {
            list.push({
                id: items[i].GUID,
                src: undefined,
                isAtive: items[i].Ativo,
                description: items[i].Title,
                url: items[i].Link.Url
            });
        }
    };
    /**
     * Receives the response from an Sharepoint API request and processes it adding ther URL of the images to an ISPImage array.
     * @param items the response with from the SharePoint API
     * @param list of images to load the urls onto.
     */
    BannerWp.prototype._processUrls = function (items, list) {
        for (var i = 0; i < items.length; i++) {
            list[i].src = items[i].EncodedAbsUrl;
        }
    };
    BannerWp.prototype._validateNextGallery = function (nextProps) {
        var nextGallery = {
            bullets: nextProps.showBulletButtons,
            scroll: nextProps.scrollSpeed,
            thumpnails: nextProps.showThumpnails
        };
        return nextGallery != this.gallery;
    };
    return BannerWp;
}(React.Component));
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = BannerWp;

//# sourceMappingURL=BannerWp.js.map
